@@ -7,12 +7,11 @@ Comprehensive and flexible Federated Learning Simulator!
 
 """
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
 
 from . import datasets
 from . import distributed
 from . import local
-from . import losses
 from . import models
 from . import scores
 from . import utils
@@ -23,6 +22,5 @@ __all__ = [
     "models",
     "local",
     "scores",
-    "losses",
     "utils",
 ]
