@@ -2,7 +2,7 @@
 Utils
 -----
 
-andy functions and classes used in FedSim package
+Small handy functions and classes used in FedSim package
 
 """
 
@@ -11,11 +11,7 @@ from .aggregators import SerialAggregator
 from .convert_parameters import initialize_module
 from .convert_parameters import vector_to_parameters_like
 from .convert_parameters import vectorize_module
-from .dict_ops import add_dict_to_dict
-from .dict_ops import add_in_dict
-from .dict_ops import append_dict_to_dict
 from .dict_ops import apply_on_dict
-from .dict_ops import reduce_dict
 from .import_utils import get_from_module
 from .random_utils import set_seed
 from .storage import Storage
@@ -24,11 +20,7 @@ __all__ = [
     "vectorize_module",
     "initialize_module",
     "vector_to_parameters_like",
-    "add_dict_to_dict",
-    "add_in_dict",
-    "append_dict_to_dict",
     "apply_on_dict",
-    "reduce_dict",
     "get_from_module",
     "set_seed",
     "SerialAggregator",
